@@ -18,4 +18,4 @@ from .CMmodelwrapper import CMmodelwrapper
 from .modelwrapper import ModelWrapper
 from .newmetric import NewMetric
 from .newmetric_child import NewMetricChild
-from .newmetric_child_perf import NewMetricChild
\ No newline at end of file
+from .newmetric_child_perf import PerfNewMetricChild
