@@ -1085,31 +1085,31 @@ class Fairness:
         metric_box = HBox([box4f, box2p], layout=Layout(width="auto"))
 
 
-        PATH = os.getcwd()
+        PATH = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
 
         if model_type != 'Uplift':
-            image1 = IPython.display.Image(filename=PATH + "\\veritas\\resources\\widget\\perf_class_jpg.jpg", width=300, height=500)
+            image1 = IPython.display.Image(filename=PATH + "\\resources\\widget\\perf_class_jpg.jpg", width=300, height=500)
             A = widgets.Image(
                 value=image1.data,
                 format='jpg',
                 width=260
             )
 
-            image2 = IPython.display.Image(filename=PATH + "\\veritas\\resources\\widget\\fair_class_jpg.jpg", width=300, height=500)
+            image2 = IPython.display.Image(filename=PATH + "\\resources\\widget\\fair_class_jpg.jpg", width=300, height=500)
             B = widgets.Image(
                 value=image2.data,
                 format='jpg',
                 width=260
             )
         else:
-            image1 = IPython.display.Image(filename=PATH + "\\veritas\\resources\\widget\\perf_uplift_jpg.jpg", width=300, height=500)
+            image1 = IPython.display.Image(filename=PATH + "\\resources\\widget\\perf_uplift_jpg.jpg", width=300, height=500)
             A = widgets.Image(
                 value=image1.data,
                 format='jpg',
                 width=260
             )
 
-            image2 = IPython.display.Image(filename=PATH + "\\veritas\\resources\\widget\\fair_uplift_jpg.jpg", width=300, height=500)
+            image2 = IPython.display.Image(filename=PATH + "\\resources\\widget\\fair_uplift_jpg.jpg", width=300, height=500)
             B = widgets.Image(
                 value=image2.data,
                 format='jpg',
@@ -1459,4 +1459,4 @@ class NpEncoder(json.JSONEncoder):
         if isinstance(obj, np.ndarray):
             return obj.tolist()
         return super(NpEncoder, self).default(obj)
- 
\ No newline at end of file
+ 
