@@ -1,7 +1,7 @@
 import numpy as np
 import sklearn.metrics as skm
-from veritas.fairness.fairness_metrics import FairnessMetrics
-from veritas.fairness.modelrates import *
+from ..fairness.fairness_metrics import FairnessMetrics
+from ..fairness.modelrates import *
 
 
 ### in compute_tradeoff(), check for y_prob and return None.
