@@ -5,7 +5,7 @@ from sklearn.metrics import confusion_matrix
 from copy import deepcopy
 import multiprocessing
 import math
-from veritas.config.constants import Constants
+from .config.constants import Constants
 from .ErrorCatcher import VeritasError
 
 def check_datatype(obj_in):
@@ -523,4 +523,4 @@ def test_function_cm():
     if result[0]['perf_metric_values'] == sample[0]['perf_metric_values'] and result[1] == sample[1]:
         print("Evaluation of customer marketing performed normally")
     else:
-        print('The test results are abnormal')
\ No newline at end of file
+        print('The test results are abnormal')
